@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2026 sqlmap developers (https://sqlmap.org)
 See the file 'LICENSE' for copying permission
 """
 
@@ -16,7 +16,7 @@ _defaults = {
     "timeout": 30,
     "retries": 3,
     "csrfRetries": 0,
-    "saFreq": 0,
+    "safeFreq": 0,
     "threads": 1,
     "level": 1,
     "risk": 1,
