@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2026 sqlmap developers (https://sqlmap.org)
 See the file 'LICENSE' for copying permission
 """
 
@@ -75,7 +75,7 @@ class Fingerprint(GenericFingerprint):
 
             if not result:
                 warnMsg = "the back-end DBMS is not %s" % DBMS.VIRTUOSO
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
                 return False
 
@@ -84,6 +84,6 @@ class Fingerprint(GenericFingerprint):
             return True
         else:
             warnMsg = "the back-end DBMS is not %s" % DBMS.VIRTUOSO
-            logger.warn(warnMsg)
+            logger.warning(warnMsg)
 
             return False
